mn: Mean values

View source: R/mn.R

mnR Documentation

Mean values

Description

Mean values of the data set for gaussian membership function

Usage

mn(x)

Arguments

x

A data set in the form of document-term matrix

Value

Mean values for individual row of the input data set X.

Examples

x<-matrix(c(12,9,14,11,21,16,15,24,20,17,14,11),nrow=4)
mn(x)
#[1] 17.66667 14.00000 14.33333 15.33333

ipsfs documentation built on June 21, 2022, 5:07 p.m.

Related to mn in ipsfs...