| mn | R Documentation |
Mean values of the data set for gaussian membership function
mn(x)
x |
A data set in the form of document-term matrix |
Mean values for individual row of the input data set X.
x<-matrix(c(12,9,14,11,21,16,15,24,20,17,14,11),nrow=4) mn(x) #[1] 17.66667 14.00000 14.33333 15.33333
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.